/**
 * Copyright French Prime minister Office/SGMAP/DINSIC/Vitam Program (2019-2020)
 * and the signatories of the "VITAM - Accord du Contributeur" agreement.
 *
 * contact@programmevitam.fr
 *
 * This software is a computer program whose purpose is to implement
 * implement a digital archiving front-office system for the secure and
 * efficient high volumetry VITAM solution.
 *
 * This software is governed by the CeCILL-C license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL-C
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C license and that you accept its terms.
 */
package fr.gouv.vitamui.iam.common.dto;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import org.hibernate.validator.constraints.Length;

import com.fasterxml.jackson.annotation.JsonInclude;

import fr.gouv.vitamui.commons.api.domain.AddressDto;
import fr.gouv.vitamui.commons.api.domain.IdDto;
import fr.gouv.vitamui.commons.api.domain.LanguageDto;
import fr.gouv.vitamui.commons.api.domain.OwnerDto;
import fr.gouv.vitamui.iam.common.enums.OtpEnum;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * A DTO with an identifier.
 *
 *
 */
@Getter
@Setter
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class CustomerDto extends IdDto {

    private static final long serialVersionUID = 997428479132350296L;

    @NotNull
    @Length(min = 4, max = 25)
    private String code;

    @NotNull
    @Length(max = 100)
    private String name;

    @NotNull
    @Length(max = 250)
    private String companyName;

    private boolean enabled;

    @NotNull
    private LanguageDto language;

    @NotNull
    private Integer passwordRevocationDelay;

    @NotNull
    private OtpEnum otp;

    @NotNull
    @Size(min = 1)
    private List<String> emailDomains;

    @NotNull
    private String defaultEmailDomain;

    @NotNull
    private AddressDto address;

    private String internalCode;

    private boolean subrogeable = false;

    private boolean readonly = false;

    // Owners embedded
    @JsonInclude(JsonInclude.Include.NON_NULL)
    private List<OwnerDto> owners = null;

    // no validations for identifier. Because during the creation step, the identifier is set by the backend.
    private String identifier;

    private boolean hasCustomGraphicIdentity = false;

    private Map<String, String> themeColors = new HashMap<>();

    private boolean rgpdAlert = false;

    private int rgpdAlertDelay;
}
